package onebit.chrdraw;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.util.Collection;
import java.util.Map;

import javax.swing.JComponent;

import onebit.chrdraw.chr.Command;
import onebit.chrdraw.chr.Font;
import onebit.chrdraw.chr.FontUtils;
import onebit.chrdraw.chr.Glyph;
import onebit.chrdraw.chr.Opcode;

public class TextLine extends JComponent {

  Font font;
  String text;
  Double scale;
  
  public TextLine(Font font, String text, Double scale) {
    super();
    this.font = font;
    this.text = text;
    this.scale = scale;
    
    int width = (int)(scale * FontUtils.calculateStringWidth(font, text));
    int height = (int)(scale * (font.getOriginToTopOfCapital() + 1 - font.getOriginToBottomDescender()));
    
    setPreferredSize(new Dimension(width, height));
  }
  
  @Override
  protected void paintComponent(Graphics g) {
    super.paintComponent(g);

    g.setColor(Color.BLUE);

    int y0 = font.getOriginToTopOfCapital() + 1;
    
    int x0 = 0;
    for (int i = 0; i < text.length(); i++) {
      int y, x = y = 0;
      
      Character ch = Character.valueOf(text.charAt(i));
      Map<Character, Glyph> characters = font.getCharacters();
      Glyph glyph = characters.get(ch);
      if (glyph != null) {
        int width = glyph.getWidth();
  
        Collection<Command> commands = glyph.getCommands();
        for (Command command : commands) {
          Opcode opcode = command.getOpcode();
          int tX = command.getX();
          int tY = command.getY();
          switch (opcode) {
            case DRAW_TO:
              int sX1 = (int)(scale * (x0 + x));
              int sY1 = (int)(scale * (y0 - 1 - y));
              int sX2 = (int)(scale * (x0 + tX));
              int sY2 = (int)(scale * (y0 - 1 - tY));
              g.drawLine(sX1, sY1, sX2, sY2);
            case MOVE_POINTER:
              x = tX;
              y = tY;
              break;
            case DO_SCAN:
            case END:
            default:
          }
        }
        
        x0 += width;
      }
    }
  }

}
